summaryrefslogtreecommitdiffstats
path: root/khtml/rendering
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/rendering')
-rw-r--r--khtml/rendering/bidi.cpp26
-rw-r--r--khtml/rendering/break_lines.cpp2
-rw-r--r--khtml/rendering/break_lines.h8
-rw-r--r--khtml/rendering/enumerate.cpp2
-rw-r--r--khtml/rendering/font.cpp4
-rw-r--r--khtml/rendering/render_applet.cpp14
-rw-r--r--khtml/rendering/render_arena.cpp4
-rw-r--r--khtml/rendering/render_block.cpp2
-rw-r--r--khtml/rendering/render_body.cpp4
-rw-r--r--khtml/rendering/render_body.h2
-rw-r--r--khtml/rendering/render_box.cpp6
-rw-r--r--khtml/rendering/render_box.h2
-rw-r--r--khtml/rendering/render_canvas.cpp16
-rw-r--r--khtml/rendering/render_canvas.h2
-rw-r--r--khtml/rendering/render_container.cpp4
-rw-r--r--khtml/rendering/render_flow.cpp6
-rw-r--r--khtml/rendering/render_flow.h2
-rw-r--r--khtml/rendering/render_form.cpp26
-rw-r--r--khtml/rendering/render_frames.cpp42
-rw-r--r--khtml/rendering/render_generated.cpp4
-rw-r--r--khtml/rendering/render_image.cpp4
-rw-r--r--khtml/rendering/render_layer.cpp56
-rw-r--r--khtml/rendering/render_layer.h4
-rw-r--r--khtml/rendering/render_list.cpp12
-rw-r--r--khtml/rendering/render_object.cpp32
-rw-r--r--khtml/rendering/render_object.h8
-rw-r--r--khtml/rendering/render_replaced.cpp10
-rw-r--r--khtml/rendering/render_style.cpp6
-rw-r--r--khtml/rendering/render_style.h10
-rw-r--r--khtml/rendering/render_table.cpp2
-rw-r--r--khtml/rendering/render_text.cpp14
-rw-r--r--khtml/rendering/render_text.h4
32 files changed, 170 insertions, 170 deletions
diff --git a/khtml/rendering/break_lines.cpp b/khtml/rendering/break_lines.cpp
index 2ae5b53c7..a0d314cee 100644
--- a/khtml/rendering/break_lines.cpp
+++ b/khtml/rendering/break_lines.cpp
@@ -1,7 +1,7 @@
#include <break_lines.h>
#include <klibloader.h>
#include "tqcstring.h"
-#include <textcodec.h>
+#include <tqtextcodec.h>
#include <tqcleanuphandler.h>
#include <config.h>
diff --git a/khtml/rendering/break_lines.h b/khtml/rendering/break_lines.h
index 5176e5fb0..ed6df2aab 100644
--- a/khtml/rendering/break_lines.h
+++ b/khtml/rendering/break_lines.h
@@ -6,7 +6,7 @@
namespace khtml {
/*
- array of unicode codes where breaking shouldn't occur.
+ array of tqunicode codes where breaking shouldn't occur.
(in sorted order because of using with binary search)
these are currently for Japanese, though simply adding
Korean, Chinese ones should work as well
@@ -122,7 +122,7 @@ namespace khtml {
inline bool isBreakable( const TQChar *str, const int pos, int len )
{
const TQChar *c = str+pos;
- unsigned short ch = c->unicode();
+ unsigned short ch = c->tqunicode();
if ( ch > 0xff ) {
// not latin1, need to do more sophisticated checks for asian fonts
unsigned char row = c->row();
@@ -147,8 +147,8 @@ namespace khtml {
return false;
// do binary search in dontbreak[]
- return break_bsearch(dontbreakbefore, c->unicode()) &&
- break_bsearch(dontbreakafter, (str+(pos-1))->unicode());
+ return break_bsearch(dontbreakbefore, c->tqunicode()) &&
+ break_bsearch(dontbreakafter, (str+(pos-1))->tqunicode());
} else // no asian font
return c->isSpace();
} else {
diff --git a/khtml/rendering/enumerate.cpp b/khtml/rendering/enumerate.cpp
index 9cfe149ad..57445c12b 100644
--- a/khtml/rendering/enumerate.cpp
+++ b/khtml/rendering/enumerate.cpp
@@ -138,7 +138,7 @@ TQString toHebrew( int number ) {
TQString letter;
if (number < 1) return TQString::number(number);
if (number>999) {
- letter = toHebrew(number/1000) + TQString::fromLatin1("'");
+ letter = toHebrew(number/1000) + TQString::tqfromLatin1("'");
number = number%1000;
}
diff --git a/khtml/rendering/font.cpp b/khtml/rendering/font.cpp
index a33f0e082..766c89840 100644
--- a/khtml/rendering/font.cpp
+++ b/khtml/rendering/font.cpp
@@ -293,7 +293,7 @@ int Font::width( TQChar *chs, int, int pos, int len, int start, int end, int toA
const TQString qstr = cstr.string();
if ( scFont ) {
const TQString upper = qstr.upper();
- const TQChar *uc = qstr.unicode();
+ const TQChar *uc = qstr.tqunicode();
const TQFontMetrics sc_fm( *scFont );
for ( int i = 0; i < len; ++i ) {
if ( (uc+i)->category() == TQChar::Letter_Lowercase )
@@ -407,7 +407,7 @@ bool Font::isFontScalable(TQFontDatabase& db, const TQFont& font)
/* Cache size info */
if (!scalSizesCache)
scalSizesCache = new TQMap<ScalKey, TQValueList<int> >;
- (*scalSizesCache)[key] = db.smoothSizes(font.family(), db.styleString(font));
+ (*scalSizesCache)[key] = db.tqsmoothSizes(font.family(), db.styleString(font));
}
}
diff --git a/khtml/rendering/render_applet.cpp b/khtml/rendering/render_applet.cpp
index fce22f7c8..3a00589e2 100644
--- a/khtml/rendering/render_applet.cpp
+++ b/khtml/rendering/render_applet.cpp
@@ -123,22 +123,22 @@ void RenderApplet::processArguments(const TQMap<TQString, TQString> &args)
KJavaApplet* applet = w ? w->applet() : 0;
if ( applet ) {
- applet->setBaseURL( args[TQString::fromLatin1("baseURL") ] );
- applet->setAppletClass( args[TQString::fromLatin1("code") ] );
+ applet->setBaseURL( args[TQString::tqfromLatin1("baseURL") ] );
+ applet->setAppletClass( args[TQString::tqfromLatin1("code") ] );
- TQString str = args[TQString::fromLatin1("codeBase") ];
+ TQString str = args[TQString::tqfromLatin1("codeBase") ];
if( !str.isEmpty() )
applet->setCodeBase( str );
- str = args[TQString::fromLatin1("name") ];
+ str = args[TQString::tqfromLatin1("name") ];
if( !str.isNull() )
applet->setAppletName( str );
else
- applet->setAppletName( args[TQString::fromLatin1("code") ] );
+ applet->setAppletName( args[TQString::tqfromLatin1("code") ] );
- str = args[TQString::fromLatin1("archive") ];
+ str = args[TQString::tqfromLatin1("archive") ];
if( !str.isEmpty() )
- applet->setArchives( args[TQString::fromLatin1("archive") ] );
+ applet->setArchives( args[TQString::tqfromLatin1("archive") ] );
}
}
diff --git a/khtml/rendering/render_arena.cpp b/khtml/rendering/render_arena.cpp
index 99fbf4f4d..023b98e36 100644
--- a/khtml/rendering/render_arena.cpp
+++ b/khtml/rendering/render_arena.cpp
@@ -88,7 +88,7 @@ void* RenderArena::allocate(size_t size)
#else
void* result = 0;
- // Ensure we have correct alignment for pointers. Important for Tru64
+ // Ensure we have correct tqalignment for pointers. Important for Tru64
size = KHTML_ROUNDUP(size, sizeof(void*));
// Check recyclers first
@@ -130,7 +130,7 @@ void RenderArena::free(size_t size, void* ptr)
VALGRIND_MEMPOOL_FREE(findContainingArena(&m_pool, ptr)->base, ptr);
#endif
- // Ensure we have correct alignment for pointers. Important for Tru64
+ // Ensure we have correct tqalignment for pointers. Important for Tru64
size = KHTML_ROUNDUP(size, sizeof(void*));
// See if it's a size that we recycle
diff --git a/khtml/rendering/render_block.cpp b/khtml/rendering/render_block.cpp
index ccbb6fad0..5b30e2a58 100644
--- a/khtml/rendering/render_block.cpp
+++ b/khtml/rendering/render_block.cpp
@@ -881,7 +881,7 @@ static inline bool isAnonymousWhitespace( RenderObject* o ) {
return false;
RenderObject *fc = o->firstChild();
return fc && fc == o->lastChild() && fc->isText() && static_cast<RenderText *>(fc)->stringLength() == 1 &&
- static_cast<RenderText *>(fc)->text()[0].unicode() == ' ';
+ static_cast<RenderText *>(fc)->text()[0].tqunicode() == ' ';
}
RenderObject* RenderBlock::handleCompactChild(RenderObject* child, CompactInfo& compactInfo, const MarginInfo& marginInfo, bool& handled)
diff --git a/khtml/rendering/render_body.cpp b/khtml/rendering/render_body.cpp
index 930ec358c..2ed114a53 100644
--- a/khtml/rendering/render_body.cpp
+++ b/khtml/rendering/render_body.cpp
@@ -81,11 +81,11 @@ void RenderBody::paintBoxDecorations(PaintInfo& paintInfo, int _tx, int _ty)
}
-void RenderBody::repaint(Priority p)
+void RenderBody::tqrepaint(Priority p)
{
RenderObject *cb = containingBlock();
if(cb)
- cb->repaint(p);
+ cb->tqrepaint(p);
}
void RenderBody::layout()
diff --git a/khtml/rendering/render_body.h b/khtml/rendering/render_body.h
index 7951f73e1..17c237e91 100644
--- a/khtml/rendering/render_body.h
+++ b/khtml/rendering/render_body.h
@@ -40,7 +40,7 @@ public:
virtual bool isBody() const { return true; }
virtual const char *renderName() const { return "RenderBody"; }
- virtual void repaint(Priority p=NormalPriority);
+ virtual void tqrepaint(Priority p=NormalPriority);
virtual void layout();
virtual void setStyle(RenderStyle* style);
diff --git a/khtml/rendering/render_box.h b/khtml/rendering/render_box.h
index c0c618d5c..78b85b5f4 100644
--- a/khtml/rendering/render_box.h
+++ b/khtml/rendering/render_box.h
@@ -87,7 +87,7 @@ public:
virtual int rightmostPosition(bool includeOverflowInterior=true, bool includeSelf=true) const;
virtual int leftmostPosition(bool includeOverflowInterior=true, bool includeSelf=true) const;
- virtual void repaint(Priority p=NormalPriority);
+ virtual void tqrepaint(Priority p=NormalPriority);
virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
diff --git a/khtml/rendering/render_canvas.h b/khtml/rendering/render_canvas.h
index 17f279d7b..cd4ef30ca 100644
--- a/khtml/rendering/render_canvas.h
+++ b/khtml/rendering/render_canvas.h
@@ -61,7 +61,7 @@ public:
KHTMLView *view() const { return m_view; }
- virtual void repaint(Priority p=NormalPriority);
+ virtual void tqrepaint(Priority p=NormalPriority);
virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
void repaintViewRectangle(int x, int y, int w, int h, bool asap=false);
bool needsFullRepaint() const;
diff --git a/khtml/rendering/render_flow.cpp b/khtml/rendering/render_flow.cpp
index ae579bd46..97dd40468 100644
--- a/khtml/rendering/render_flow.cpp
+++ b/khtml/rendering/render_flow.cpp
@@ -267,7 +267,7 @@ bool RenderFlow::hitTestLines(NodeInfo& i, int x, int y, int tx, int ty, HitTest
}
-void RenderFlow::repaint(Priority prior)
+void RenderFlow::tqrepaint(Priority prior)
{
if (isInlineFlow()) {
// Find our leftmost position.
@@ -280,7 +280,7 @@ void RenderFlow::repaint(Priority prior)
if (curr == firstLineBox() || curr->xPos() < left)
left = curr->xPos();
- // Now invalidate a rectangle.
+ // Now tqinvalidate a rectangle.
int ow = style() ? style()->outlineSize() : 0;
// We need to add in the relative position offsets of any inlines (including us) up to our
@@ -306,7 +306,7 @@ void RenderFlow::repaint(Priority prior)
effectiveWidth()+ow*2, effectiveHeight()+ow*2, prior);
}
else
- return RenderBox::repaint(prior);
+ return RenderBox::tqrepaint(prior);
}
}
diff --git a/khtml/rendering/render_flow.h b/khtml/rendering/render_flow.h
index 1e23822bb..3267a92f1 100644
--- a/khtml/rendering/render_flow.h
+++ b/khtml/rendering/render_flow.h
@@ -69,7 +69,7 @@ public:
void paintLines(PaintInfo& i, int _tx, int _ty);
bool hitTestLines(NodeInfo& i, int x, int y, int tx, int ty, HitTestAction hitTestAction);
- virtual void repaint(Priority p=NormalPriority);
+ virtual void tqrepaint(Priority p=NormalPriority);
virtual int highestPosition(bool includeOverflowInterior=true, bool includeSelf=true) const;
virtual int lowestPosition(bool includeOverflowInterior=true, bool includeSelf=true) const;
diff --git a/khtml/rendering/render_form.cpp b/khtml/rendering/render_form.cpp
index d55b32fe4..5c53f0250 100644
--- a/khtml/rendering/render_form.cpp
+++ b/khtml/rendering/render_form.cpp
@@ -155,8 +155,8 @@ void RenderCheckBox::calcMinMaxWidth()
KHTMLAssert( !minMaxKnown() );
TQCheckBox *cb = static_cast<TQCheckBox *>( m_widget );
- TQSize s( cb->tqstyle().pixelMetric( TQStyle::PM_IndicatorWidth ),
- cb->tqstyle().pixelMetric( TQStyle::PM_IndicatorHeight ) );
+ TQSize s( cb->tqstyle().tqpixelMetric( TQStyle::PM_IndicatorWidth ),
+ cb->tqstyle().tqpixelMetric( TQStyle::PM_IndicatorHeight ) );
setIntrinsicWidth( s.width() );
setIntrinsicHeight( s.height() );
@@ -207,8 +207,8 @@ void RenderRadioButton::calcMinMaxWidth()
KHTMLAssert( !minMaxKnown() );
TQRadioButton *rb = static_cast<TQRadioButton *>( m_widget );
- TQSize s( rb->tqstyle().pixelMetric( TQStyle::PM_ExclusiveIndicatorWidth ),
- rb->tqstyle().pixelMetric( TQStyle::PM_ExclusiveIndicatorHeight ) );
+ TQSize s( rb->tqstyle().tqpixelMetric( TQStyle::PM_ExclusiveIndicatorWidth ),
+ rb->tqstyle().tqpixelMetric( TQStyle::PM_ExclusiveIndicatorHeight ) );
setIntrinsicWidth( s.width() );
setIntrinsicHeight( s.height() );
@@ -260,17 +260,17 @@ void RenderSubmitButton::calcMinMaxWidth()
bool empty = raw.isEmpty();
if ( empty )
- raw = TQString::fromLatin1("X");
+ raw = TQString::tqfromLatin1("X");
TQFontMetrics fm = pb->fontMetrics();
TQSize ts = fm.size( ShowPrefix, raw);
TQSize s(pb->tqstyle().tqsizeFromContents( TQStyle::CT_PushButton, pb, ts )
.expandedTo(TQApplication::globalStrut()));
- int margin = pb->tqstyle().pixelMetric( TQStyle::PM_ButtonMargin, pb) +
- pb->tqstyle().pixelMetric( TQStyle::PM_DefaultFrameWidth, pb ) * 2;
+ int margin = pb->tqstyle().tqpixelMetric( TQStyle::PM_ButtonMargin, pb) +
+ pb->tqstyle().tqpixelMetric( TQStyle::PM_DefaultFrameWidth, pb ) * 2;
int w = ts.width() + margin;
int h = s.height();
if (pb->isDefault() || pb->autoDefault()) {
- int dbw = pb->tqstyle().pixelMetric( TQStyle::PM_ButtonDefaultIndicator, pb ) * 2;
+ int dbw = pb->tqstyle().tqpixelMetric( TQStyle::PM_ButtonDefaultIndicator, pb ) * 2;
w += dbw;
}
@@ -1018,7 +1018,7 @@ void RenderSelect::updateFromElement()
DOMString label = optElem->getAttribute(ATTR_LABEL);
if (!label.isEmpty())
text = label.string();
- text = TQString::fromLatin1(" ")+text;
+ text = TQString::tqfromLatin1(" ")+text;
}
if(m_useListBox) {
@@ -1406,7 +1406,7 @@ void TextAreaWidget::slotReplaceNext()
}
if (!(m_replace->options() & KReplaceDialog::PromptOnReplace)) {
- viewport()->setUpdatesEnabled(false);
+ viewport()->tqsetUpdatesEnabled(false);
}
KFind::Result res = KFind::NoMatch;
@@ -1449,7 +1449,7 @@ void TextAreaWidget::slotReplaceNext()
}
if (!(m_replace->options() & KReplaceDialog::PromptOnReplace)) {
- viewport()->setUpdatesEnabled(true);
+ viewport()->tqsetUpdatesEnabled(true);
repaintChanged();
}
@@ -1738,13 +1738,13 @@ TQString RenderTextArea::text()
paragraphText = paragraphText.left(pl); //Snip invented space.
for (int l = 0; l < pl; ++l) {
if (lindex != w->lineOfChar(p, l)) {
- paragraphText.insert(l+ll++, TQString::fromLatin1("\n"));
+ paragraphText.insert(l+ll++, TQString::tqfromLatin1("\n"));
lindex = w->lineOfChar(p, l);
}
}
txt += paragraphText;
if (p < w->paragraphs() - 1)
- txt += TQString::fromLatin1("\n");
+ txt += TQString::tqfromLatin1("\n");
}
}
else
diff --git a/khtml/rendering/render_frames.cpp b/khtml/rendering/render_frames.cpp
index bc3f00be4..9f58a0a4f 100644
--- a/khtml/rendering/render_frames.cpp
+++ b/khtml/rendering/render_frames.cpp
@@ -728,16 +728,16 @@ void RenderPartObject::updateWidget()
HTMLParamElementImpl *p = static_cast<HTMLParamElementImpl *>( child );
TQString aStr = p->name();
- aStr += TQString::fromLatin1("=\"");
+ aStr += TQString::tqfromLatin1("=\"");
aStr += p->value();
- aStr += TQString::fromLatin1("\"");
+ aStr += TQString::tqfromLatin1("\"");
TQString name_lower = p->name().lower();
- if (name_lower == TQString::fromLatin1("type") && objbase->id() != ID_APPLET) {
+ if (name_lower == TQString::tqfromLatin1("type") && objbase->id() != ID_APPLET) {
objbase->setServiceType(p->value());
} else if (url.isEmpty() &&
- (name_lower == TQString::fromLatin1("src") ||
- name_lower == TQString::fromLatin1("movie") ||
- name_lower == TQString::fromLatin1("code"))) {
+ (name_lower == TQString::tqfromLatin1("src") ||
+ name_lower == TQString::tqfromLatin1("movie") ||
+ name_lower == TQString::tqfromLatin1("code"))) {
url = p->value();
}
params.append(aStr);
@@ -754,8 +754,8 @@ void RenderPartObject::updateWidget()
}
}
}
- params.append( TQString::fromLatin1("__KHTML__PLUGINEMBED=\"YES\"") );
- params.append( TQString::fromLatin1("__KHTML__PLUGINBASEURL=\"%1\"").arg(element()->getDocument()->baseURL().url()));
+ params.append( TQString::tqfromLatin1("__KHTML__PLUGINEMBED=\"YES\"") );
+ params.append( TQString::tqfromLatin1("__KHTML__PLUGINBASEURL=\"%1\"").arg(element()->getDocument()->baseURL().url()));
HTMLEmbedElementImpl *embed = 0;
TQString classId;
@@ -775,18 +775,18 @@ void RenderPartObject::updateWidget()
}
classId = objbase->classId;
- params.append( TQString::fromLatin1("__KHTML__CLASSID=\"%1\"").arg( classId ) );
- params.append( TQString::fromLatin1("__KHTML__CODEBASE=\"%1\"").arg( objbase->getAttribute(ATTR_CODEBASE).string() ) );
+ params.append( TQString::tqfromLatin1("__KHTML__CLASSID=\"%1\"").arg( classId ) );
+ params.append( TQString::tqfromLatin1("__KHTML__CODEBASE=\"%1\"").arg( objbase->getAttribute(ATTR_CODEBASE).string() ) );
if (!objbase->getAttribute(ATTR_WIDTH).isEmpty())
- params.append( TQString::fromLatin1("WIDTH=\"%1\"").arg( objbase->getAttribute(ATTR_WIDTH).string() ) );
+ params.append( TQString::tqfromLatin1("WIDTH=\"%1\"").arg( objbase->getAttribute(ATTR_WIDTH).string() ) );
else if (embed && !embed->getAttribute(ATTR_WIDTH).isEmpty()) {
- params.append( TQString::fromLatin1("WIDTH=\"%1\"").arg( embed->getAttribute(ATTR_WIDTH).string() ) );
+ params.append( TQString::tqfromLatin1("WIDTH=\"%1\"").arg( embed->getAttribute(ATTR_WIDTH).string() ) );
objbase->setAttribute(ATTR_WIDTH, embed->getAttribute(ATTR_WIDTH));
}
if (!objbase->getAttribute(ATTR_HEIGHT).isEmpty())
- params.append( TQString::fromLatin1("HEIGHT=\"%1\"").arg( objbase->getAttribute(ATTR_HEIGHT).string() ) );
+ params.append( TQString::tqfromLatin1("HEIGHT=\"%1\"").arg( objbase->getAttribute(ATTR_HEIGHT).string() ) );
else if (embed && !embed->getAttribute(ATTR_HEIGHT).isEmpty()) {
- params.append( TQString::fromLatin1("HEIGHT=\"%1\"").arg( embed->getAttribute(ATTR_HEIGHT).string() ) );
+ params.append( TQString::tqfromLatin1("HEIGHT=\"%1\"").arg( embed->getAttribute(ATTR_HEIGHT).string() ) );
objbase->setAttribute(ATTR_HEIGHT, embed->getAttribute(ATTR_HEIGHT));
}
@@ -808,7 +808,7 @@ void RenderPartObject::updateWidget()
serviceType = "application/x-activex-handler";
#endif
- if(classId.find(TQString::fromLatin1("D27CDB6E-AE6D-11cf-96B8-444553540000")) >= 0) {
+ if(classId.find(TQString::tqfromLatin1("D27CDB6E-AE6D-11cf-96B8-444553540000")) >= 0) {
// It is ActiveX, but the nsplugin system handling
// should also work, that's why we don't override the
// serviceType with application/x-activex-handler
@@ -817,17 +817,17 @@ void RenderPartObject::updateWidget()
// with nspluginviewer (Niko)
serviceType = "application/x-shockwave-flash";
}
- else if(classId.find(TQString::fromLatin1("CFCDAA03-8BE4-11cf-B84B-0020AFBBCCFA")) >= 0)
+ else if(classId.find(TQString::tqfromLatin1("CFCDAA03-8BE4-11cf-B84B-0020AFBBCCFA")) >= 0)
serviceType = "audio/x-pn-realaudio-plugin";
- else if(classId.find(TQString::fromLatin1("8AD9C840-044E-11D1-B3E9-00805F499D93")) >= 0 ||
- objbase->classId.find(TQString::fromLatin1("CAFEEFAC-0014-0000-0000-ABCDEFFEDCBA")) >= 0)
+ else if(classId.find(TQString::tqfromLatin1("8AD9C840-044E-11D1-B3E9-00805F499D93")) >= 0 ||
+ objbase->classId.find(TQString::tqfromLatin1("CAFEEFAC-0014-0000-0000-ABCDEFFEDCBA")) >= 0)
serviceType = "application/x-java-applet";
// http://www.apple.com/quicktime/tools_tips/tutorials/activex.html
- else if(classId.find(TQString::fromLatin1("02BF25D5-8C17-4B23-BC80-D3488ABDDC6B")) >= 0)
+ else if(classId.find(TQString::tqfromLatin1("02BF25D5-8C17-4B23-BC80-D3488ABDDC6B")) >= 0)
serviceType = "video/quicktime";
// http://msdn.microsoft.com/library/en-us/dnwmt/html/adding_windows_media_to_web_pages__etse.asp?frame=true
- else if(objbase->classId.find(TQString::fromLatin1("6BF52A52-394A-11d3-B153-00C04F79FAA6")) >= 0 ||
- classId.find(TQString::fromLatin1("22D6f312-B0F6-11D0-94AB-0080C74C7E95")) >= 0)
+ else if(objbase->classId.find(TQString::tqfromLatin1("6BF52A52-394A-11d3-B153-00C04F79FAA6")) >= 0 ||
+ classId.find(TQString::tqfromLatin1("22D6f312-B0F6-11D0-94AB-0080C74C7E95")) >= 0)
serviceType = "video/x-msvideo";
else
diff --git a/khtml/rendering/render_generated.cpp b/khtml/rendering/render_generated.cpp
index 17c65fc9c..f5fc70687 100644
--- a/khtml/rendering/render_generated.cpp
+++ b/khtml/rendering/render_generated.cpp
@@ -53,7 +53,7 @@ void RenderCounterBase::calcMinMaxWidth()
generateContent();
if (str) str->deref();
- str = new DOM::DOMStringImpl(m_item.unicode(), m_item.length());
+ str = new DOM::DOMStringImpl(m_item.tqunicode(), m_item.length());
str->ref();
RenderText::calcMinMaxWidth();
@@ -379,7 +379,7 @@ void RenderGlyph::paint(PaintInfo& paintInfo, int _tx, int _ty)
diamond[2] = TQPoint(x+s, y+2*s);
diamond[3] = TQPoint(x, y+s);
p->setBrush( color );
- p->drawConvexPolygon( diamond, 0, 4 );
+ p->tqdrawConvexPolygon( diamond, 0, 4 );
return;
}
case LNONE:
diff --git a/khtml/rendering/render_image.cpp b/khtml/rendering/render_image.cpp
index 46104adb8..b5357bba1 100644
--- a/khtml/rendering/render_image.cpp
+++ b/khtml/rendering/render_image.cpp
@@ -266,7 +266,7 @@ void RenderImage::paint(PaintInfo& paintInfo, int _tx, int _ty)
if ( !berrorPic ) {
//qDebug("qDrawShadePanel %d/%d/%d/%d", _tx + leftBorder, _ty + topBorder, cWidth, cHeight);
qDrawShadePanel( paintInfo.p, _tx + leftBorder + leftPad, _ty + topBorder + topPad, cWidth, cHeight,
- KApplication::palette().inactive(), true, 1 );
+ KApplication::tqpalette().inactive(), true, 1 );
}
TQPixmap const* pix = i ? &i->pixmap() : 0;
if(berrorPic && pix && (cWidth >= pix->width()+4) && (cHeight >= pix->height()+4) )
@@ -416,7 +416,7 @@ void RenderImage::notifyFinished(CachedObject *finishedObj)
if ( ( m_cachedImage == finishedObj || m_oldImage == finishedObj ) && m_oldImage ) {
m_oldImage->deref( this );
m_oldImage = 0;
- repaint();
+ tqrepaint();
}
RenderReplaced::notifyFinished(finishedObj);
diff --git a/khtml/rendering/render_layer.h b/khtml/rendering/render_layer.h
index a8f1e5adc..1176a63a3 100644
--- a/khtml/rendering/render_layer.h
+++ b/khtml/rendering/render_layer.h
@@ -190,7 +190,7 @@ public:
void checkInlineRelOffset(const RenderObject* o, int& x, int& y);
short scrollXOffset() { return m_scrollX; }
int scrollYOffset() { return m_scrollY; }
- void scrollToOffset(int x, int y, bool updateScrollbars = true, bool repaint = true);
+ void scrollToOffset(int x, int y, bool updateScrollbars = true, bool tqrepaint = true);
void scrollToXOffset(int x) { scrollToOffset(x, m_scrollY); }
void scrollToYOffset(int y) { scrollToOffset(m_scrollX, y); }
void showScrollbar(Qt::Orientation, bool);
@@ -202,7 +202,7 @@ public:
void paintScrollbars(RenderObject::PaintInfo& pI);
void checkScrollbarsAfterLayout();
void slotValueChanged(int);
- void repaint(Priority p=NormalPriority, bool markForRepaint = false);
+ void tqrepaint(Priority p=NormalPriority, bool markForRepaint = false);
void updateScrollPositionFromScrollbars();
void updateLayerPosition();
diff --git a/khtml/rendering/render_list.cpp b/khtml/rendering/render_list.cpp
index 769b79670..c88f103d3 100644
--- a/khtml/rendering/render_list.cpp
+++ b/khtml/rendering/render_list.cpp
@@ -333,7 +333,7 @@ void RenderListMarker::paint(PaintInfo& paintInfo, int _tx, int _ty)
diamond[2] = TQPoint(x+s, y+2*s);
diamond[3] = TQPoint(x, y+s);
p->setBrush( color );
- p->drawConvexPolygon( diamond, 0, 4 );
+ p->tqdrawConvexPolygon( diamond, 0, 4 );
return;
}
case LNONE:
@@ -344,21 +344,21 @@ void RenderListMarker::paint(PaintInfo& paintInfo, int _tx, int _ty)
if( style()->direction() == LTR) {
p->drawText(_tx, _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, m_item);
p->drawText(_tx + fm.width(m_item), _ty, 0, 0, Qt::AlignLeft|TQt::DontClip,
- TQString::fromLatin1(". "));
+ TQString::tqfromLatin1(". "));
}
else {
- const TQString& punct(TQString::fromLatin1(" ."));
+ const TQString& punct(TQString::tqfromLatin1(" ."));
p->drawText(_tx, _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, punct);
p->drawText(_tx + fm.width(punct), _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, m_item);
}
} else {
if (style()->direction() == LTR) {
- const TQString& punct(TQString::fromLatin1(". "));
+ const TQString& punct(TQString::tqfromLatin1(". "));
p->drawText(_tx-offset/2, _ty, 0, 0, Qt::AlignRight|TQt::DontClip, punct);
p->drawText(_tx-offset/2-fm.width(punct), _ty, 0, 0, Qt::AlignRight|TQt::DontClip, m_item);
}
else {
- const TQString& punct(TQString::fromLatin1(" ."));
+ const TQString& punct(TQString::tqfromLatin1(" ."));
p->drawText(_tx+offset/2, _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, punct);
p->drawText(_tx+offset/2+fm.width(punct), _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, m_item);
}
@@ -543,7 +543,7 @@ void RenderListMarker::calcMinMaxWidth()
default:
KHTMLAssert(false);
}
- m_markerWidth = fm.width(m_item) + fm.width(TQString::fromLatin1(". "));
+ m_markerWidth = fm.width(m_item) + fm.width(TQString::tqfromLatin1(". "));
}
end:
diff --git a/khtml/rendering/render_replaced.cpp b/khtml/rendering/render_replaced.cpp
index 7653b746c..01379930a 100644
--- a/khtml/rendering/render_replaced.cpp
+++ b/khtml/rendering/render_replaced.cpp
@@ -183,7 +183,7 @@ bool RenderWidget::event( TQEvent *e )
return true;
TQWidgetResizeEvent *re = static_cast<TQWidgetResizeEvent *>(e);
m_widget->resize( re->w, re->h );
- repaint();
+ tqrepaint();
}
// eat all events - except if this is a frame (in which case KHTMLView handles it all)
if ( ::tqqt_cast<KHTMLView *>( m_widget ) )
@@ -543,10 +543,10 @@ static void copyWidget(const TQRect& r, TQPainter *p, TQWidget *widget, int tx,
}
}
}
- TQMemArray<TQRect> br = blit.rects();
+ TQMemArray<TQRect> br = blit.tqrects();
const int cnt = br.size();
- const bool external = p->device()->isExtDev();
+ const bool external = p->tqdevice()->isExtDev();
TQPixmap* const pm = PaintBuffer::grab( widget->size() );
if (!pm)
{
@@ -558,7 +558,7 @@ static void copyWidget(const TQRect& r, TQPainter *p, TQWidget *widget, int tx,
if ( external ) {
// even hackier!
TQPainter pt( pm );
- const TQColor c = widget->colorGroup().base();
+ const TQColor c = widget->tqcolorGroup().base();
for (int i = 0; i < cnt; ++i)
pt.fillRect( br[i], c );
} else {
@@ -672,7 +672,7 @@ bool RenderWidget::eventFilter(TQObject* /*o*/, TQEvent* e)
// don't allow the widget to react to wheel event unless its
// currently focused. this avoids accidentally changing a select box
// or something while wheeling a webpage.
- if (tqApp->focusWidget() != widget() &&
+ if (tqApp->tqfocusWidget() != widget() &&
widget()->focusPolicy() <= TQ_StrongFocus) {
TQT_TQWHEELEVENT(e)->ignore();
TQApplication::sendEvent(view(), e);
diff --git a/khtml/rendering/render_style.h b/khtml/rendering/render_style.h
index c60a7ef47..59e38277d 100644
--- a/khtml/rendering/render_style.h
+++ b/khtml/rendering/render_style.h
@@ -39,7 +39,7 @@
#include <tqfont.h>
#include <tqfontmetrics.h>
#include <tqptrlist.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqapplication.h>
#include "dom/dom_misc.h"
@@ -919,7 +919,7 @@ protected:
PseudoId _styleType : 4;
bool _hasClip : 1;
unsigned _pseudoBits : 8;
- EUnicodeBidi _unicodeBidi : 2;
+ EUnicodeBidi _tqunicodeBidi : 2;
// non CSS2 non-inherited
bool _textOverflow : 1; // Whether or not lines that spill out should be truncated with "..."
@@ -991,7 +991,7 @@ protected:
noninherited_flags.f._styleType = NOPSEUDO;
noninherited_flags.f._hasClip = false;
noninherited_flags.f._pseudoBits = 0;
- noninherited_flags.f._unicodeBidi = initialUnicodeBidi();
+ noninherited_flags.f._tqunicodeBidi = initialUnicodeBidi();
noninherited_flags.f._textOverflow = initialTextOverflow();
noninherited_flags.f.unused = 0;
}
@@ -1108,7 +1108,7 @@ public:
LengthBox clip() const { return visual->clip; }
bool hasClip() const { return noninherited_flags.f._hasClip; }
- EUnicodeBidi unicodeBidi() const { return noninherited_flags.f._unicodeBidi; }
+ EUnicodeBidi tqunicodeBidi() const { return noninherited_flags.f._tqunicodeBidi; }
EClear clear() const { return noninherited_flags.f._clear; }
ETableLayout tableLayout() const { return noninherited_flags.f._table_layout; }
@@ -1272,7 +1272,7 @@ public:
void setClip( Length top, Length right, Length bottom, Length left );
void setHasClip( bool b ) { noninherited_flags.f._hasClip = b; }
- void setUnicodeBidi( EUnicodeBidi b ) { noninherited_flags.f._unicodeBidi = b; }
+ void setUnicodeBidi( EUnicodeBidi b ) { noninherited_flags.f._tqunicodeBidi = b; }
void setClear(EClear v) { noninherited_flags.f._clear = v; }
void setTableLayout(ETableLayout v) { noninherited_flags.f._table_layout = v; }
diff --git a/khtml/rendering/render_table.cpp b/khtml/rendering/render_table.cpp
index 2cf1bf1f9..26e9c26d5 100644
--- a/khtml/rendering/render_table.cpp
+++ b/khtml/rendering/render_table.cpp
@@ -482,7 +482,7 @@ void RenderTable::paint( PaintInfo& pI, int _tx, int _ty)
#if 0
TQString m;
for (uint i = 0; i < borderStyles.count(); i++)
- m += TQString("%1 ").arg((*borderStyles.at(i)).width());
+ m += TQString("%1 ").arg((*borderStyles.tqat(i)).width());
kdDebug(6040) << m << endl;
#endif
TQValueListIterator<CollapsedBorderValue> it = borderStyles.begin();
diff --git a/khtml/rendering/render_text.cpp b/khtml/rendering/render_text.cpp
index f5fa2e373..cc41a1688 100644
--- a/khtml/rendering/render_text.cpp
+++ b/khtml/rendering/render_text.cpp
@@ -738,7 +738,7 @@ void RenderText::deleteInlineBoxes(RenderArena* arena)
if (!arena)
arena = renderArena();
for(unsigned int i=0; i < len; i++) {
- InlineTextBox* s = m_lines.at(i);
+ InlineTextBox* s = m_lines.tqat(i);
if (s)
s->detach(arena);
m_lines.remove(i);
@@ -1036,7 +1036,7 @@ void RenderText::calcMinMaxWidth()
bool firstLine = true;
for(int i = 0; i < len; i++)
{
- unsigned short c = str->s[i].unicode();
+ unsigned short c = str->s[i].tqunicode();
bool isNewline = false;
// If line-breaks survive to here they are preserved
@@ -1056,7 +1056,7 @@ void RenderText::calcMinMaxWidth()
continue;
int wordlen = 0;
- while( i+wordlen < len && (i+wordlen == 0 || str->s[i+wordlen].unicode() != SOFT_HYPHEN) &&
+ while( i+wordlen < len && (i+wordlen == 0 || str->s[i+wordlen].tqunicode() != SOFT_HYPHEN) &&
!(isBreakable( str->s, i+wordlen, str->l )) )
wordlen++;
@@ -1328,11 +1328,11 @@ short RenderText::width() const
return w;
}
-void RenderText::repaint(Priority p)
+void RenderText::tqrepaint(Priority p)
{
RenderObject *cb = containingBlock();
if(cb)
- cb->repaint(p);
+ cb->tqrepaint(p);
}
bool RenderText::isFixedWidthFont() const
@@ -1464,13 +1464,13 @@ static TQString quoteAndEscapeNonPrintables(const TQString &s)
TQString result;
result += '"';
for (uint i = 0; i != s.length(); ++i) {
- TQChar c = s.at(i);
+ TQChar c = s.tqat(i);
if (c == '\\') {
result += "\\\\";
} else if (c == '"') {
result += "\\\"";
} else {
- ushort u = c.unicode();
+ ushort u = c.tqunicode();
if (u >= 0x20 && u < 0x7F) {
result += c;
} else {
diff --git a/khtml/rendering/render_text.h b/khtml/rendering/render_text.h
index 50132fbc7..0923837b3 100644
--- a/khtml/rendering/render_text.h
+++ b/khtml/rendering/render_text.h
@@ -36,7 +36,7 @@
class TQPainter;
class TQFontMetrics;
-// Define a constant for soft hyphen's unicode value.
+// Define a constant for soft hyphen's tqunicode value.
#define SOFT_HYPHEN 173
const int cNoTruncation = -1;
@@ -247,7 +247,7 @@ public:
virtual short marginLeft() const { return style()->marginLeft().minWidth(0); }
virtual short marginRight() const { return style()->marginRight().minWidth(0); }
- virtual void repaint(Priority p=NormalPriority);
+ virtual void tqrepaint(Priority p=NormalPriority);
bool hasBreakableChar() const { return m_hasBreakableChar; }
const TQFontMetrics &metrics(bool firstLine) const;
diff --git a/khtml/rendering/bidi.cpp b/khtml/rendering/bidi.cpp
index bd010047a..30beadd7c 100644
--- a/khtml/rendering/bidi.cpp
+++ b/khtml/rendering/bidi.cpp
@@ -242,7 +242,7 @@ static inline RenderObject *Bidinext(RenderObject *par, RenderObject *current, B
if (!oldEndOfInline && !current->isFloating() && !current->isReplaced() && !current->isPositioned()) {
next = current->firstChild();
if ( next && adjustEmbedding ) {
- EUnicodeBidi ub = next->style()->unicodeBidi();
+ EUnicodeBidi ub = next->style()->tqunicodeBidi();
if ( ub != UBNormal && !emptyRun ) {
EDirection dir = next->style()->direction();
TQChar::Direction d = ( ub == Embed ? ( dir == RTL ? TQChar::DirRLE : TQChar::DirLRE )
@@ -261,7 +261,7 @@ static inline RenderObject *Bidinext(RenderObject *par, RenderObject *current, B
while (current && current != par) {
next = current->nextSibling();
if (next) break;
- if ( adjustEmbedding && current->style()->unicodeBidi() != UBNormal && !emptyRun ) {
+ if ( adjustEmbedding && current->style()->tqunicodeBidi() != UBNormal && !emptyRun ) {
embed( TQChar::DirPDF, bidi );
}
current = current->parent();
@@ -454,7 +454,7 @@ static void checkMidpoints(BidiIterator& lBreak, BidiState &bidi)
// Don't shave a character off the endpoint if it was from a soft hyphen.
RenderText* textObj = static_cast<RenderText*>(endpoint.obj);
if (endpoint.pos+1 < textObj->length() &&
- textObj->text()[endpoint.pos+1].unicode() == SOFT_HYPHEN)
+ textObj->text()[endpoint.pos+1].tqunicode() == SOFT_HYPHEN)
return;
}
endpoint.pos--;
@@ -484,7 +484,7 @@ static void appendRunsForObject(int start, int end, RenderObject* obj, BidiState
bool haveNextMidpoint = (smidpoints && sCurrMidpoint < sNumMidpoints);
BidiIterator nextMidpoint;
if (haveNextMidpoint)
- nextMidpoint = smidpoints->at(sCurrMidpoint);
+ nextMidpoint = smidpoints->tqat(sCurrMidpoint);
if (betweenMidpoints) {
if (!(haveNextMidpoint && nextMidpoint.obj == obj))
return;
@@ -1241,7 +1241,7 @@ void RenderBlock::bidiReorderLine(const BidiIterator &start, const BidiIterator
}
// this causes the operator ++ to open and close embedding levels as needed
// for the CSS unicode-bidi property
adjustEmbedding = true;
bidi.current.increment( bidi );
adjustEmbedding = false;
@@ -1611,11 +1611,11 @@ BidiIterator RenderBlock::findNextLineBreak(BidiIterator &start, BidiState &bidi
// be skipped.
while (!start.atEnd() && (start.obj->isInlineFlow() || (!start.obj->style()->preserveWS() && !start.obj->isBR() &&
#ifndef QT_NO_UNICODETABLES
- ( (start.current().unicode() == (ushort)0x0020) || // ASCII space
- (start.current().unicode() == (ushort)0x0009) || // ASCII tab
- (start.current().unicode() == (ushort)0x000A) || // ASCII line feed
- (start.current().unicode() == (ushort)0x000C) || // ASCII form feed
- (start.current().unicode() == (ushort)0x200B) || // Zero-width space
+ ( (start.current().tqunicode() == (ushort)0x0020) || // ASCII space
+ (start.current().tqunicode() == (ushort)0x0009) || // ASCII tab
+ (start.current().tqunicode() == (ushort)0x000A) || // ASCII line feed
+ (start.current().tqunicode() == (ushort)0x000C) || // ASCII form feed
+ (start.current().tqunicode() == (ushort)0x200B) || // Zero-width space
start.obj->isFloatingOrPositioned() )
#else
( start.current() == ' ' || start.current() == '\n' || start.obj->isFloatingOrPositioned() )
@@ -1824,7 +1824,7 @@ BidiIterator RenderBlock::findNextLineBreak(BidiIterator &start, BidiState &bidi
isLineEmpty = false;
// Check for soft hyphens. Go ahead and ignore them.
- if (c.unicode() == SOFT_HYPHEN && pos > 0) {
+ if (c.tqunicode() == SOFT_HYPHEN && pos > 0) {
nextIsSoftBreakable = true;
if (!ignoringSpaces) {
// Ignore soft hyphens
@@ -1911,7 +1911,7 @@ BidiIterator RenderBlock::findNextLineBreak(BidiIterator &start, BidiState &bidi
lBreak.endOfInline = false;
}
goto end;
- } else if ( (pos > 1 && str[pos-1].unicode() == SOFT_HYPHEN) )
+ } else if ( (pos > 1 && str[pos-1].tqunicode() == SOFT_HYPHEN) )
// Subtract the width of the soft hyphen out since we fit on a line.
tmpW -= t->width(pos-1, 1, f);
}
@@ -2189,7 +2189,7 @@ BidiIterator RenderBlock::findNextLineBreak(BidiIterator &start, BidiState &bidi
// For soft hyphens on line breaks, we have to chop out the midpoints that made us
// ignore the hyphen so that it will render at the end of the line.
TQChar c = static_cast<RenderText*>(lBreak.obj)->text()[lBreak.pos-1];
- if (c.unicode() == SOFT_HYPHEN)
+ if (c.tqunicode() == SOFT_HYPHEN)
chopMidpointsAt(lBreak.obj, lBreak.pos-2);
}
@@ -1241,7 +1241,7 @@ void RenderBlock::bidiReorderLine(const BidiIterator &start, const BidiIterator
}
// this causes the operator ++ to open and close embedding levels as needed
- // for the CSS unicode-bidi property
+ // for the CSS tqunicode-bidi property
adjustEmbedding = true;
bidi.current.increment( bidi );
diff --git a/khtml/rendering/render_box.cpp b/khtml/rendering/render_box.cpp
index 7400752ac..e63115361 100644
--- a/khtml/rendering/render_box.cpp
+++ b/khtml/rendering/render_box.cpp
@@ -346,7 +346,7 @@ void RenderBox::paintRootBoxDecorations(PaintInfo& paintInfo, int _tx, int _ty)
}
if( !bgColor.isValid() && canvas()->view())
- bgColor = canvas()->view()->palette().active().color(TQColorGroup::Base);
+ bgColor = canvas()->view()->tqpalette().active().color(TQColorGroup::Base);
int w = width();
int h = height();
@@ -622,7 +622,7 @@ void RenderBox::paintBackgroundExtended(TQPainter *p, const TQColor &c, const Ba
sy+=b.y()-cy;
cx=b.x();cy=b.y();cw=b.width();ch=b.height();
}
// restrict painting to repaint-clip
if (cy < clipy) {
ch -= (clipy - cy);
sy += (clipy - cy);
@@ -795,7 +795,7 @@ void RenderBox::position(InlineBox* box, int /*from*/, int /*len*/, bool /*rever
setPos( box->xPos(), box->yPos() );
}
-void RenderBox::repaint(Priority prior)
+void RenderBox::tqrepaint(Priority prior)
{
int ow = style() ? style()->outlineSize() : 0;
if( isInline() && !isReplaced() )
@@ -622,7 +622,7 @@ void RenderBox::paintBackgroundExtended(TQPainter *p, const TQColor &c, const Ba
cx=b.x();cy=b.y();cw=b.width();ch=b.height();
}
- // restrict painting to repaint-clip
+ // restrict painting to tqrepaint-clip
if (cy < clipy) {
ch -= (clipy - cy);
diff --git a/khtml/rendering/render_canvas.cpp b/khtml/rendering/render_canvas.cpp
index e8540eba6..e5947369d 100644
--- a/khtml/rendering/render_canvas.cpp
+++ b/khtml/rendering/render_canvas.cpp
@@ -329,7 +329,7 @@ void RenderCanvas::paintBoxDecorations(PaintInfo& paintInfo, int /*_tx*/, int /*
if ((firstChild() && firstChild()->style()->visibility() == VISIBLE) || !view())
return;
- paintInfo.p->fillRect(paintInfo.r, view()->palette().active().color(TQColorGroup::Base));
+ paintInfo.p->fillRect(paintInfo.r, view()->tqpalette().active().color(TQColorGroup::Base));
}
void RenderCanvas::repaintRectangle(int x, int y, int w, int h, Priority p, bool f)
@@ -372,13 +372,13 @@ void RenderCanvas::scheduleDeferredRepaints()
if (!needsFullRepaint()) {
TQValueList<RenderObject*>::const_iterator it;
for ( it = m_dirtyChildren.begin(); it != m_dirtyChildren.end(); ++it )
- (*it)->repaint();
+ (*it)->tqrepaint();
}
- //kdDebug(6040) << "scheduled deferred repaints: " << m_dirtyChildren.count() << " needed full repaint: " << needsFullRepaint() << endl;
+ //kdDebug(6040) << "scheduled deferred repaints: " << m_dirtyChildren.count() << " needed full tqrepaint: " << needsFullRepaint() << endl;
m_dirtyChildren.clear();
}
-void RenderCanvas::repaint(Priority p)
+void RenderCanvas::tqrepaint(Priority p)
{
if (m_view && !m_staticMode) {
if (p == RealtimePriority) {
@@ -567,7 +567,7 @@ void RenderCanvas::setSelection(RenderObject *s, int sp, RenderObject *e, int ep
TQRect updateRect;
// Don't use repaint() because it will cause all rects to
// be united (see khtmlview::scheduleRepaint()). Instead
// just draw damage rects for objects that have a change
// in selection state.
@@ -651,9 +651,9 @@ void RenderCanvas::clearSelection(bool doRepaint)
{
if (o->selectionState()!=SelectionNone)
if (doRepaint)
- o->repaint();
+ o->tqrepaint();
o->setSelectionState(SelectionNone);
- o->repaint();
+ o->tqrepaint();
RenderObject* no;
if ( !(no = o->firstChild()) )
if ( !(no = o->nextSibling()) )
@@ -669,7 +669,7 @@ void RenderCanvas::clearSelection(bool doRepaint)
if (m_selectionEnd) {
m_selectionEnd->setSelectionState(SelectionNone);
if (doRepaint)
- m_selectionEnd->repaint();
+ m_selectionEnd->tqrepaint();
}
// set selection start & end to 0
@@ -567,7 +567,7 @@ void RenderCanvas::setSelection(RenderObject *s, int sp, RenderObject *e, int ep
TQRect updateRect;
- // Don't use repaint() because it will cause all rects to
+ // Don't use tqrepaint() because it will cause all rects to
// be united (see khtmlview::scheduleRepaint()). Instead
// just draw damage rects for objects that have a change
diff --git a/khtml/rendering/render_container.cpp b/khtml/rendering/render_container.cpp
index 69f987477..13f17c08d 100644
--- a/khtml/rendering/render_container.cpp
+++ b/khtml/rendering/render_container.cpp
@@ -170,11 +170,11 @@ RenderObject* RenderContainer::removeChildNode(RenderObject* oldChild)
KHTMLAssert(oldChild->parent() == this);
// So that we'll get the appropriate dirty bit set (either that a normal flow child got yanked or
// that a positioned child got yanked). We also repaint, so that the area exposed when the child
// disappears gets repainted properly.
if ( document()->renderer() ) {
oldChild->setNeedsLayoutAndMinMaxRecalc();
- oldChild->repaint();
+ oldChild->tqrepaint();
// Keep our layer hierarchy updated.
oldChild->removeLayers(enclosingLayer());
@@ -170,11 +170,11 @@ RenderObject* RenderContainer::removeChildNode(RenderObject* oldChild)
KHTMLAssert(oldChild->parent() == this);
// So that we'll get the appropriate dirty bit set (either that a normal flow child got yanked or
- // that a positioned child got yanked). We also repaint, so that the area exposed when the child
+ // that a positioned child got yanked). We also tqrepaint, so that the area exposed when the child
// disappears gets repainted properly.
if ( document()->renderer() ) {
diff --git a/khtml/rendering/render_layer.cpp b/khtml/rendering/render_layer.cpp
index 96b0236cb..3427bf1dc 100644
--- a/khtml/rendering/render_layer.cpp
+++ b/khtml/rendering/render_layer.cpp
@@ -168,7 +168,7 @@ TQRegion RenderLayer::paintedRegion(RenderLayer* rootLayer)
if (m_negZOrderList) {
uint count = m_negZOrderList->count();
for (uint i = 0; i < count; i++) {
- RenderLayer* child = m_negZOrderList->at(i);
+ RenderLayer* child = m_negZOrderList->tqat(i);
r += child->paintedRegion(rootLayer);
}
}
@@ -188,19 +188,19 @@ TQRegion RenderLayer::paintedRegion(RenderLayer* rootLayer)
if (m_posZOrderList) {
uint count = m_posZOrderList->count();
for (uint i = 0; i < count; i++) {
- RenderLayer* child = m_posZOrderList->at(i);
+ RenderLayer* child = m_posZOrderList->tqat(i);
r += child->paintedRegion(rootLayer);
}
}
return r;
}
-void RenderLayer::repaint( Priority p, bool markForRepaint )
+void RenderLayer::tqrepaint( Priority p, bool markForRepaint )
{
if (markForRepaint && m_markedForRepaint)
return;
for (RenderLayer* child = firstChild(); child; child = child->nextSibling())
- child->repaint( p, markForRepaint );
+ child->tqrepaint( p, markForRepaint );
TQRect layerBounds, damageRect, fgrect;
calculateRects(renderer()->canvas()->layer(), renderer()->viewRect(), layerBounds, damageRect, fgrect);
m_visibleRect = damageRect.intersect( layerBounds );
@@ -213,7 +213,7 @@ void RenderLayer::repaint( Priority p, bool markForRepaint )
void RenderLayer::updateLayerPositions(RenderLayer* rootLayer, bool doFullRepaint, bool checkForRepaint)
{
if (doFullRepaint) {
- m_object->repaint();
+ m_object->tqrepaint();
checkForRepaint = doFullRepaint = false;
}
@@ -266,7 +266,7 @@ void RenderLayer::updateWidgetMasks(RenderLayer* rootLayer)
m_region = TQRect(0,0,sv->contentsWidth(),sv->contentsHeight());
for (uint i = 0; i < count; i++) {
- RenderLayer* child = m_posZOrderList->at(i);
+ RenderLayer* child = m_posZOrderList->tqat(i);
if (child->zIndex() == 0 && child->renderer()->style()->position() == STATIC)
continue; // we don't know the widget's exact stacking position within flow
m_region -= child->paintedRegion(rootLayer);
@@ -537,7 +537,7 @@ void RenderLayer::checkInlineRelOffset(const RenderObject* o, int& x, int& y)
y += sy;
}
-void RenderLayer::scrollToOffset(int x, int y, bool updateScrollbars, bool repaint)
+void RenderLayer::scrollToOffset(int x, int y, bool updateScrollbars, bool tqrepaint)
{
if (renderer()->style()->overflowX() != OMARQUEE || !renderer()->hasOverflowClip()) {
if (x < 0) x = 0;
@@ -569,9 +569,9 @@ void RenderLayer::scrollToOffset(int x, int y, bool updateScrollbars, bool repai
// Fire the scroll DOM event.
m_object->element()->dispatchHTMLEvent(EventImpl::SCROLL_EVENT, true, false);
- // Just schedule a full repaint of our object.
- if (repaint)
- m_object->repaint(RealtimePriority);
+ // Just schedule a full tqrepaint of our object.
+ if (tqrepaint)
+ m_object->tqrepaint(RealtimePriority);
if (updateScrollbars) {
if (m_hBar)
@@ -637,7 +637,7 @@ int RenderLayer::verticalScrollbarWidth()
#ifdef APPLE_CHANGES
return m_vBar->width();
#else
- return m_vBar->tqstyle().pixelMetric(TQStyle::PM_ScrollBarExtent);
+ return m_vBar->tqstyle().tqpixelMetric(TQStyle::PM_ScrollBarExtent);
#endif
}
@@ -650,7 +650,7 @@ int RenderLayer::horizontalScrollbarHeight()
#ifdef APPLE_CHANGES
return m_hBar->height();
#else
- return m_hBar->tqstyle().pixelMetric(TQStyle::PM_ScrollBarExtent);
+ return m_hBar->tqstyle().tqpixelMetric(TQStyle::PM_ScrollBarExtent);
#endif
}
@@ -691,7 +691,7 @@ void RenderLayer::positionScrollbars(const TQRect& absBounds)
TQScrollBar *b = m_hBar;
if (!m_hBar)
b = m_vBar;
- int sw = b->tqstyle().pixelMetric(TQStyle::PM_ScrollBarExtent);
+ int sw = b->tqstyle().tqpixelMetric(TQStyle::PM_ScrollBarExtent);
if (m_vBar) {
TQRect vBarRect = TQRect(tx + w - sw + 1, ty, sw, h - (m_hBar ? sw : 0) + 1);
@@ -898,7 +898,7 @@ void RenderLayer::paintLayer(RenderLayer* rootLayer, TQPainter *p,
if (m_negZOrderList) {
uint count = m_negZOrderList->count();
for (uint i = 0; i < count; i++) {
- RenderLayer* child = m_negZOrderList->at(i);
+ RenderLayer* child = m_negZOrderList->tqat(i);
child->paintLayer(rootLayer, p, paintDirtyRect, selectionOnly);
}
}
@@ -946,7 +946,7 @@ void RenderLayer::paintLayer(RenderLayer* rootLayer, TQPainter *p,
if (m_posZOrderList) {
uint count = m_posZOrderList->count();
for (uint i = 0; i < count; i++) {
- RenderLayer* child = m_posZOrderList->at(i);
+ RenderLayer* child = m_posZOrderList->tqat(i);
child->paintLayer(rootLayer, p, paintDirtyRect, selectionOnly);
}
}
@@ -1026,7 +1026,7 @@ RenderLayer* RenderLayer::nodeAtPointForLayer(RenderLayer* rootLayer, RenderObje
if (m_posZOrderList) {
uint count = m_posZOrderList->count();
for (int i = count-1; i >= 0; i--) {
- RenderLayer* child = m_posZOrderList->at(i);
+ RenderLayer* child = m_posZOrderList->tqat(i);
insideLayer = child->nodeAtPointForLayer(rootLayer, info, xMousePos, yMousePos, hitTestRect);
if (insideLayer)
return insideLayer;
@@ -1057,7 +1057,7 @@ RenderLayer* RenderLayer::nodeAtPointForLayer(RenderLayer* rootLayer, RenderObje
if (m_negZOrderList) {
uint count = m_negZOrderList->count();
for (int i = count-1; i >= 0; i--) {
- RenderLayer* child = m_negZOrderList->at(i);
+ RenderLayer* child = m_negZOrderList->tqat(i);
insideLayer = child->nodeAtPointForLayer(rootLayer, info, xMousePos, yMousePos, hitTestRect);
if (insideLayer)
return insideLayer;
@@ -1261,8 +1261,8 @@ static void sortByZOrder(TQPtrVector<RenderLayer>* buffer,
for (uint i = end-1; i > start; i--) {
bool sorted = true;
for (uint j = start; j < i; j++) {
- RenderLayer* elt = buffer->at(j);
- RenderLayer* elt2 = buffer->at(j+1);
+ RenderLayer* elt = buffer->tqat(j);
+ RenderLayer* elt2 = buffer->tqat(j+1);
if (elt->zIndex() > elt2->zIndex()) {
sorted = false;
buffer->insert(j, elt2);
@@ -1279,8 +1279,8 @@ static void sortByZOrder(TQPtrVector<RenderLayer>* buffer,
sortByZOrder(buffer, mergeBuffer, start, mid);
sortByZOrder(buffer, mergeBuffer, mid, end);
- RenderLayer* elt = buffer->at(mid-1);
- RenderLayer* elt2 = buffer->at(mid);
+ RenderLayer* elt = buffer->tqat(mid-1);
+ RenderLayer* elt2 = buffer->tqat(mid);
// Handle the fast common case (of equal z-indices). The list may already
// be completely sorted.
@@ -1293,26 +1293,26 @@ static void sortByZOrder(TQPtrVector<RenderLayer>* buffer,
uint i1 = start;
uint i2 = mid;
- elt = buffer->at(i1);
- elt2 = buffer->at(i2);
+ elt = buffer->tqat(i1);
+ elt2 = buffer->tqat(i2);
while (i1 < mid || i2 < end) {
if (i1 < mid && (i2 == end || elt->zIndex() <= elt2->zIndex())) {
mergeBuffer->insert(mergeBuffer->count(), elt);
i1++;
if (i1 < mid)
- elt = buffer->at(i1);
+ elt = buffer->tqat(i1);
}
else {
mergeBuffer->insert(mergeBuffer->count(), elt2);
i2++;
if (i2 < end)
- elt2 = buffer->at(i2);
+ elt2 = buffer->tqat(i2);
}
}
for (uint i = start; i < end; i++)
- buffer->insert(i, mergeBuffer->at(i-start));
+ buffer->insert(i, mergeBuffer->tqat(i-start));
mergeBuffer->clear();
}
@@ -1471,7 +1471,7 @@ static void writeLayers(TQTextStream &ts, const RenderLayer* rootLayer, RenderLa
if (negList) {
for (unsigned i = 0; i != negList->count(); ++i)
- writeLayers(ts, rootLayer, negList->at(i), paintDirtyRect, indent );
+ writeLayers(ts, rootLayer, negList->tqat(i), paintDirtyRect, indent );
}
if (shouldPaint)
@@ -1485,7 +1485,7 @@ static void writeLayers(TQTextStream &ts, const RenderLayer* rootLayer, RenderLa
TQPtrVector<RenderLayer>* posList = l->posZOrderList();
if (posList) {
for (unsigned i = 0; i != posList->count(); ++i)
- writeLayers(ts, rootLayer, posList->at(i), paintDirtyRect, indent);
+ writeLayers(ts, rootLayer, posList->tqat(i), paintDirtyRect, indent);
}
}
diff --git a/khtml/rendering/render_object.cpp b/khtml/rendering/render_object.cpp
index 162ca4956..1fc72c7d8 100644
--- a/khtml/rendering/render_object.cpp
+++ b/khtml/rendering/render_object.cpp
@@ -535,9 +535,9 @@ bool RenderObject::hasStaticY() const
void RenderObject::setPixmap(const TQPixmap&, const TQRect& /*r*/, CachedImage* image)
{
//repaint bg when it finished loading
if(image && parent() && style() && style()->backgroundLayers()->containsImage(image)) {
- isBody() ? canvas()->repaint() : repaint();
+ isBody() ? canvas()->tqrepaint() : tqrepaint();
}
}
@@ -1164,15 +1164,15 @@ TQString RenderObject::information() const
<< " mB: " << marginBottom() << " qB: " << isBottomMarginQuirk()
<< "}"
<< (isTableCell() ?
- ( TQString::fromLatin1(" [r=") +
+ ( TQString::tqfromLatin1(" [r=") +
TQString::number( static_cast<const RenderTableCell *>(this)->row() ) +
- TQString::fromLatin1(" c=") +
+ TQString::tqfromLatin1(" c=") +
TQString::number( static_cast<const RenderTableCell *>(this)->col() ) +
- TQString::fromLatin1(" rs=") +
+ TQString::tqfromLatin1(" rs=") +
TQString::number( static_cast<const RenderTableCell *>(this)->rowSpan() ) +
- TQString::fromLatin1(" cs=") +
+ TQString::tqfromLatin1(" cs=") +
TQString::number( static_cast<const RenderTableCell *>(this)->colSpan() ) +
- TQString::fromLatin1("]") ) : TQString::null );
+ TQString::tqfromLatin1("]") ) : TQString::null );
if ( layer() )
ts << " layer=" << layer();
if ( continuation() )
@@ -1283,11 +1283,11 @@ void RenderObject::setStyle(RenderStyle *style)
m_style->outlineWidth() > style->outlineWidth() ||
(!m_style->hidesOverflow() && style->hidesOverflow()) ||
( m_style->hasClip() && !(m_style->clip() == style->clip()) ) ) ) {
// schedule a repaint with the old style
if (layer() && !isInlineFlow())
- layer()->repaint(pri);
+ layer()->tqrepaint(pri);
else
- repaint(pri);
+ tqrepaint(pri);
}
if ( ( isFloating() && m_style->floating() != style->floating() ) ||
@@ -1345,7 +1345,7 @@ void RenderObject::setStyle(RenderStyle *style)
}
setNeedsLayoutAndMinMaxRecalc();
} else if (!isText() && d >= RenderStyle::Visible) {
// a repaint is enough
if (layer()) {
if (canvas() && canvas()->needsWidgetMasks()) {
// update our widget masks
@@ -1357,9 +1357,9 @@ void RenderObject::setStyle(RenderStyle *style)
}
}
if (layer() && !isInlineFlow())
- layer()->repaint(pri);
+ layer()->tqrepaint(pri);
else
- repaint(pri);
+ tqrepaint(pri);
}
}
}
@@ -1428,9 +1428,9 @@ void RenderObject::repaintDuringLayout()
if (canvas()->needsFullRepaint() || isText())
return;
if (layer() && !isInlineFlow()) {
- layer()->repaint( NormalPriority, true );
+ layer()->tqrepaint( NormalPriority, true );
} else {
- repaint();
+ tqrepaint();
canvas()->deferredRepaint( this );
}
}
@@ -1850,7 +1850,7 @@ short RenderObject::getVerticalPosition( bool firstLine, RenderObject* ref ) con
bool checkParent = ref->isInline() && !ref->isReplacedBlock() &&
!( ref->style()->verticalAlign() == TOP || ref->style()->verticalAlign() == BOTTOM );
vpos = checkParent ? ref->verticalPositionHint( firstLine ) : 0;
- // don't allow elements nested inside text-top to have a different valignment.
+ // don't allow elements nested inside text-top to have a different vtqalignment.
if ( va == BASELINE )
return vpos;
else if ( va == LENGTH )
@@ -535,9 +535,9 @@ bool RenderObject::hasStaticY() const
void RenderObject::setPixmap(const TQPixmap&, const TQRect& /*r*/, CachedImage* image)
{
- //repaint bg when it finished loading
+ //tqrepaint bg when it finished loading
if(image && parent() && style() && style()->backgroundLayers()->containsImage(image)) {
@@ -1283,11 +1283,11 @@ void RenderObject::setStyle(RenderStyle *style)
(!m_style->hidesOverflow() && style->hidesOverflow()) ||
( m_style->hasClip() && !(m_style->clip() == style->clip()) ) ) ) {
- // schedule a repaint with the old style
+ // schedule a tqrepaint with the old style
if (layer() && !isInlineFlow())
@@ -1345,7 +1345,7 @@ void RenderObject::setStyle(RenderStyle *style)
setNeedsLayoutAndMinMaxRecalc();
} else if (!isText() && d >= RenderStyle::Visible) {
- // a repaint is enough
+ // a tqrepaint is enough
if (layer()) {
if (canvas() && canvas()->needsWidgetMasks()) {
diff --git a/khtml/rendering/render_object.h b/khtml/rendering/render_object.h
index f7f772387..e403601d3 100644
--- a/khtml/rendering/render_object.h
+++ b/khtml/rendering/render_object.h
@@ -441,7 +441,7 @@ public:
void layoutIfNeeded() { if (needsLayout()) layout(); }
// used for element state updates that can not be fixed with a
// repaint and do not need a relayout
virtual void updateFromElement() {}
// Called immediately after render-object is inserted
@@ -681,8 +681,8 @@ public:
// Used by collapsed border tables.
virtual void collectBorders(TQValueList<CollapsedBorderValue>& borderStyles);
- // force a complete repaint
- virtual void repaint(Priority p = NormalPriority) { if(m_parent) m_parent->repaint(p); }
+ // force a complete tqrepaint
+ virtual void tqrepaint(Priority p = NormalPriority) { if(m_parent) m_parent->tqrepaint(p); }
virtual void repaintRectangle(int x, int y, int w, int h, Priority p=NormalPriority, bool f=false);
virtual unsigned int length() const { return 1; }
@@ -747,7 +747,7 @@ public:
virtual int leftmostPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
virtual int highestPosition(bool /*includeOverflowInterior*/=true, bool /*includeSelf*/=true) const { return 0; }
- // recursively invalidate current layout
+ // recursively tqinvalidate current layout
// unused: void invalidateLayout();
virtual void calcVerticalMargins() {}
@@ -441,7 +441,7 @@ public:
void layoutIfNeeded() { if (needsLayout()) layout(); }
// used for element state updates that can not be fixed with a
- // repaint and do not need a relayout
+ // tqrepaint and do not need a relayout
virtual void updateFromElement() {}
// Called immediately after render-object is inserted
diff --git a/khtml/rendering/render_style.cpp b/khtml/rendering/render_style.cpp
index a71dd4116..81d0b62ed 100644
--- a/khtml/rendering/render_style.cpp
+++ b/khtml/rendering/render_style.cpp
@@ -726,7 +726,7 @@ bool RenderStyle::inheritedNotEqual( RenderStyle *other ) const
CbLayout: The containing block of the object needs a relayout.
Layout: the RenderObject needs a relayout after the style change
Visible: The change is visible, but no relayout is needed
- NonVisible: The object does need neither repaint nor relayout after
+ NonVisible: The object does need neither tqrepaint nor relayout after
the change.
### TODO:
@@ -744,7 +744,7 @@ RenderStyle::Diff RenderStyle::diff( const RenderStyle *other ) const
// EUserInput _user_input : 2; as long as :enabled is not impl'd
// ### this needs work to know more exactly if we need a relayout
// or just a repaint
// non-inherited attributes
// DataRef<StyleBoxData> box;
@@ -786,7 +786,7 @@ RenderStyle::Diff RenderStyle::diff( const RenderStyle *other ) const
!(noninherited_flags.f._position == other->noninherited_flags.f._position) ||
!(noninherited_flags.f._floating == other->noninherited_flags.f._floating) ||
!(noninherited_flags.f._flowAroundFloats == other->noninherited_flags.f._flowAroundFloats) ||
- !(noninherited_flags.f._unicodeBidi == other->noninherited_flags.f._unicodeBidi) )
+ !(noninherited_flags.f._tqunicodeBidi == other->noninherited_flags.f._tqunicodeBidi) )
return CbLayout;
}
@@ -744,7 +744,7 @@ RenderStyle::Diff RenderStyle::diff( const RenderStyle *other ) const
// EUserInput _user_input : 2; as long as :enabled is not impl'd
// ### this needs work to know more exactly if we need a relayout
-// or just a repaint
+// or just a tqrepaint
// non-inherited attributes
// DataRef<StyleBoxData> box;